var annotated =
[
    [ "CGAL", null, [
      [ "Monge_via_jet_fitting", "classCGAL_1_1Monge__via__jet__fitting.html", "classCGAL_1_1Monge__via__jet__fitting" ]
    ] ],
    [ "DataKernel", "classDataKernel.html", "classDataKernel" ],
    [ "LocalKernel", "classLocalKernel.html", "classLocalKernel" ]
];